//
//  SHADMobBanner.h
//  SHADMob
//
//  Created by jinkai on 15/12/21.
//  Copyright © 2015年 sohu. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
/**
 *  Banner广告错误枚举类型
 */
typedef NS_ENUM(NSInteger, SHADMobBannerErrorType) {
    /** 未知错误 */
    SHADMobBannerErrorUnknow = 1,
    /** 无广告数据 */
    SHADMobBannerErrorNodata,
    /** appId/itemspaceid/developerid传入错误或空值 */
    SHADMobBannerErrorKeyEmptyOrWrong,
    /** 广告尺寸错误 */
    SHADMobBannerErrorFrameSize,
    /** 网络连接失败 */
    SHADMobBannerErrorNetworkNotReach,
    /** 下发数据格式错误 */
    SHADMobBannerErrorDataFormat,
    /** 落地页webview加载失败 */
    SHADMobBannerErrorWebview,
     /** 广告物料加载失败 */
    SHADMobBannerErrorAdMaterialLoadFail
};
/**
 *  Banner广告代理对象
 */
@protocol SHADMobBannerViewDelegate <NSObject>

@optional

/**
 *  banner广告请求数据返回成功后回调
 *
 *  @param itemspaceId 广告位id
 */
- (void)bannerViewDataDidReceivedWithItemspaceid:(NSString*)itemspaceId;

/**
 *  banner广告展示成功回调
 *  推荐在此时将返回的广告对象View添加到app中容纳广告的父窗口对象中，广告sdk将根据广告位尺寸和父窗口尺寸调整广告大小
 *  推荐父窗口大小与广告位大小等比例，以避免拉伸或压缩
 *
 *  @param itemspaceId 广告位id
 */
- (void)bannerViewDidPresentScreenWithItemspaceid:(NSString*)itemspaceId;

/**
 *  banner广告展示失败回调
 *
 *  @param error        错误类型
 *  @param itemspaceId  广告位id
 */
- (void)bannerViewFail:(SHADMobBannerErrorType)error andItemspaceid:(NSString*)itemspaceId;

/**
 *  banner广告展示完成回调
 *
 *  @param itemspaceId 广告位id
 */
- (void)bannerViewDidDismissScreenWithItemspaceid:(NSString*)itemspaceId;

/**
 *  banner广告被用户关闭时调用
 *  当打开showCloseBtn开关时，用户有可能点击关闭按钮把广告关闭
 *
 *  @param itemspaceId 广告位id
 */
- (void)bannerViewWillCloseWithItemspaceid:(NSString*)itemspaceId;

/**
 *  banner曝光回调
 *
 *  @param itemspaceId 广告位id
 */
- (void)bannerViewImpressionWithItemspaceid:(NSString*)itemspaceId;

/**
 *  banner点击回调
 *
 *  @param itemspaceId 广告位id
 */
- (void)bannerViewClickedWithItemspaceid:(NSString*)itemspaceId;

/**
 *  banner广告点击以后即将弹出全屏落地页
 *
 *  @param itemspaceId 广告位id
 */
- (void)bannerViewLoadingPageWillPresentWithItemspaceid:(NSString*)itemspaceId;

/**
 *  banner广告点击以后弹出全屏落地页完毕
 *
 *  @param itemspaceId 广告位id
 */
- (void)bannerViewLoadingPageDidPresentWithItemspaceid:(NSString*)itemspaceId;

/**
 *  全屏落地页即将被关闭
 *
 *  @param itemspaceId 广告位id
 */
- (void)bannerViewLoadingPageWillDismissWithItemspaceid:(NSString*)itemspaceId;

/**
 *  全屏落地页已经被关闭
 *
 *  @param itemspaceId 广告位id
 */
- (void)bannerViewLoadingPageDidDismissWithItemspaceid:(NSString*)itemspaceId;

@end
/**
 *  Banner广告View对象
 *  
 */
@interface SHADMobBannerView : UIView

/**
*  设置显示广告的父窗口UIViewController [必选]
*/
@property (nonatomic, weak) UIViewController *currentViewController;

/**
 *  委托 [可选]
 */
@property(nonatomic, weak) id<SHADMobBannerViewDelegate> delegate;

/**
 *  Banner广告展示关闭按钮，默认打开
 */
@property(nonatomic, assign) BOOL showCloseBtn;

/**
 *  Banner广告初始化方法
 *
 *  @param frame       banner广告展示的位置和大小
 *  @param appId       应用id
 *  @param devId       开发者id
 *  @param itemspaceId 广告位id
 *
 *  @return banner广告对象
 */
- (instancetype)initWithFrame:(CGRect)frame appId:(NSString *)appId developerId:(NSString *)devId itemspaceId:(NSString *)itemspaceId;

/**
 *  请求并展示广告
 */
- (void)requestAndShow;
@end
