//
//  SHADMobNative.h
//  SHADMob
//
//  Created by jinkai on 16/1/8.
//  Copyright © 2016年 sohu. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>
/**
 *  原生广告错误枚举类型
 */
typedef NS_ENUM(NSInteger, SHADMobNativeErrorType) {
    /** 未知错误 */
    SHADMobNativeErrorUnknow = 1,
    /** 无广告数据 */
    SHADMobNativeErrorNodata,
    /** appId/itemspaceid/developerid传入错误或空值 */
    SHADMobNativeErrorKeyEmptyOrWrong,
    /** 广告尺寸错误 */
    SHADMobNativeErrorFrameSize,
    /** 网络连接失败 */
    SHADMobNativeErrorNetworkNotReach,
    /** 下发数据格式错误 */
    SHADMobNativeErrorDataFormat,
    /** 落地页webview加载失败 */
    SHADMobNativeErrorWebview             
};
/**
 *  原生广告数据源对象
 */
@interface SHADMobNativeData : NSObject

/**
 *  广告内容字典
 *
 *  开发者调用requestDataWithCount成功后
 *  从nativeAdLoadSuccess:返回数组中获得广告数据字典
 *  通过如下键值获得数据
 *  title    标题
 *  image    图片
 */
@property (nonatomic, readonly) NSDictionary *properties;

@end

/**
 *  原生广告代理对象
 */
@protocol SHADMobNativeDelegate <NSObject>

/**
 *  广告数据获取成功后回调函数，返回广告数据对象SHADMobNativeData数组
 *
 *  @param nativeAdDataArray SHADMobNativeData对象数组
 *  @param itemspaceId       广告位id
 */
- (void)nativeAdLoadSuccess:(NSArray *)nativeAdDataArray andItemspaceId:(NSString*)itemspaceId;;

/**
 *  广告数据获取失败后回调函数
 *
 *  @param type        失败错误类型，具体含义参考SHADMobNativeErrorType
 *  @param itemspaceId 广告位id
 */
- (void)nativeAdLoadFail:(SHADMobNativeErrorType)type andItemspaceid:(NSString*)itemspaceId;;

@optional

/**
 *  落地页即将打开时回调函数
 *
 *  @param itemspaceId 广告位id
 */
- (void)nativeAdLoadingPageWillPresentSrceenWithItemspaceid:(NSString*)itemspaceId;

/**
 *  落地页关闭时回调函数
 *
 *  @param itemspaceId 广告位id
 */
- (void)nativeAdLoadingPageClosedWithItemspaceid:(NSString*)itemspaceId;


@end
/**
 *  原生广告对象
 */
@interface SHADMobNative : NSObject

/**
 *  设置显示落地页广告的父窗口UIViewController [必选]
 */
@property (nonatomic, weak) UIViewController *currentViewController;

/**
 *  委托对象 [必选]
 */
@property(nonatomic, weak) id<SHADMobNativeDelegate> delegate;

/**
 *  广告初始化方法
 *
 *  @param frame       广告位大小
 *  @param appId       应用id
 *  @param devId       开发者id
 *  @param itemspaceId 广告位id
 *
 *  @return native广告对象
 */
- (instancetype)initWithFrame:(CGRect)frame appId:(NSString *)appId developerId:(NSString *)devId itemspaceId:(NSString *)itemspaceId;

/**
 *  发起广告数据请求，并指定一次获取广告个数
 *  如果指定广告个数超出服务器能够支持数量，将会根据情况返回空广告或单个广告
 *
 *  @param count 请求广告个数
 */
- (void)requestDataWithCount:(NSInteger)count;

/**
 *  广告数据渲染完成后调用此方法，并传入当前广告数据对象
 *
 *  @param nativeAdData 当前渲染完的广告数据对象
 */
- (void)nativeAdDidShow:(SHADMobNativeData *)nativeAdData;

/**
 *  广告被点击后，调用此方法由SDK负责显示落地页
 *
 *  @param nativeAdData 当前点击的广告数据对象
 */
- (void)nativeAdClick:(SHADMobNativeData *)nativeAdData;

@end
