//
//  SHADMobOpen.h
//  SHADMob
//
//  Created by jinkai on 15/12/21.
//  Copyright © 2015年 sohu. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "UIKit/UIkit.h"
/**
 *  开屏广告错误枚举类型
 */
typedef NS_ENUM(NSInteger, SHADMobOpenErrorType) {
    /** 未知错误 */
    SHADMobOpenErrorUnknow = 1,
    /** 无广告数据 */
    SHADMobOpenErrorNodata,
    /** appId/itemspaceid/developerid传入错误或空值 */
    SHADMobOpenErrorKeyEmptyOrWrong,
    /** 网络连接失败 */
    SHADMobOpenErrorNetworkNotReach,    
    /** 下发数据格式错误 */
    SHADMobOpenErrorDataFormat,
    /** 落地页webview加载失败 */
    SHADMobOpenErrorWebview             
};

@class SHADMobOpen;
/**
 *  开屏广告代理对象
 */
@protocol SHADMobOpenDelegate <NSObject>

@optional
/**
 *  开屏广告展示成功回调
 */
- (void)openPresentSuccess;

/**
 *  开屏广告展示失败回调
 *
 *  @param error  错误信息
 */
- (void)openPresentFail:(SHADMobOpenErrorType)error;

/**
 *  开屏广告结束展示回调
 */
- (void)openDidDismissScreen;

/**
 *  开屏广告曝光回调
 */
- (void)openImpression;

/**
 *  开屏广告点击回调
 */
- (void)openClicked;

/**
 *  开屏广告落地页展示结束回调
 *
 */
- (void)openLoadingPageDidDismissScreen;

@end
/**
 *  开屏广告对象
 */
@interface SHADMobOpen : UIView
/**
 *  委托对象
 */
@property (nonatomic ,weak) id<SHADMobOpenDelegate> delegate;

/**
 *  设置开屏广告是否可以点击的属性,开屏默认可以点击。
 */
@property (nonatomic) BOOL canClick;

/**
 *  设置开屏广告是否实时请求，默认值NO，使用实时请求。
 */
@property (nonatomic) BOOL useCache;

/**
 *   插屏广告初始化方法 [必选]
 *
 *  @param appId      应用id
 *  @param devId       开发者id
 *  @param itemspaceId 广告位id
 *
 *  @return 插屏广告对象
 */
-(instancetype)initWithAppId:(NSString *)appId developerId:(NSString *)devId itemspaceId:(NSString *)itemspaceId;

/**
 *  应用启动时请求加载全屏尺寸开屏广告
 *
 *  @param keyWindow 应用主窗口
 */
- (void)loadAndDisplayUsingKeyWindow:(UIWindow *)keyWindow;

/**
 *  应用启动时请求加载半开屏尺寸开屏广告
 *
 *  @param view 展示开屏广告容器UIView
 */
//- (void)loadAndDisplayUsingContainerView:(UIView *)view;

@end
